@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0102';
 
 use v5.36;
 
@@ -117,22 +117,31 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0100
+version 0.0102
 
 =head1 SYNOPSIS
 
   use curry;
-  use Future::IO::Impl::IOAsync;
   use MIDI::RtController ();
   use MIDI::RtController::Filter::CC ();
 
-  my $rtc = MIDI::RtController->new; # * input/output required
+  my $control = MIDI::RtController->new(
+    input  => 'keyboard',
+    output => 'usb',
+  );
 
-  my $rtf = MIDI::RtController::Filter::CC->new(rtc => $rtc);
+  my $filter = MIDI::RtController::Filter::CC->new(rtc => $control);
 
-  $rtc->add_filter('breathe', note_on => $rtf->curry::breathe);
+  $filter->channel(1);
+  $filter->control(77);
+  $filter->range_bottom(10);
+  $filter->range_top(100);
+  $filter->range_step(2);
+  $filter->time_step(125_000);
 
-  $rtc->run;
+  $control->add_filter('breathe', all => $filter->curry::breathe);
+
+  $control->run;
 
 =head1 DESCRIPTION
 
@@ -143,15 +152,15 @@ control-change based L<MIDI::RtController> filters.
 
 =head2 rtc
 
-  $rtc = $rtf->rtc;
+  $rtc = $filter->rtc;
 
 The required L<MIDI::RtController> instance provided in the
 constructor.
 
 =head2 channel
 
-  $channel = $rtf->channel;
-  $rtf->channel($number);
+  $channel = $filter->channel;
+  $filter->channel($number);
 
 The current MIDI channel value between C<0> and C<15>.
 
@@ -159,8 +168,8 @@ Default: C<0>
 
 =head2 control
 
-  $control = $rtf->control;
-  $rtf->control($number);
+  $control = $filter->control;
+  $filter->control($number);
 
 The current MIDI control-change number ("CC#") between C<0> and C<127>.
 
@@ -168,8 +177,8 @@ Default: C<1> (synthesizer mod-wheel)
 
 =head2 range_bottom
 
-  $range_bottom = $rtf->range_bottom;
-  $rtf->range_bottom($number);
+  $range_bottom = $filter->range_bottom;
+  $filter->range_bottom($number);
 
 The current iteration lowest number value.
 
@@ -177,8 +186,8 @@ Default: C<0>
 
 =head2 range_top
 
-  $range_top = $rtf->range_top;
-  $rtf->range_top($number);
+  $range_top = $filter->range_top;
+  $filter->range_top($number);
 
 The current iteration highest number value.
 
@@ -186,8 +195,8 @@ Default: C<127>
 
 =head2 range_step
 
-  $range_step = $rtf->range_step;
-  $rtf->range_step($number);
+  $range_step = $filter->range_step;
+  $filter->range_step($number);
 
 A number greater than zero representing the current iteration step
 size between B<bottom> and B<top>.
@@ -196,8 +205,8 @@ Default: C<1>
 
 =head2 time_step
 
-  $time_step = $rtf->time_step;
-  $rtf->time_step($number);
+  $time_step = $filter->time_step;
+  $filter->time_step($number);
 
 The current iteration step in microseconds (where
 C<1,000,000> = C<1> second).
@@ -206,8 +215,8 @@ Default: C<250_000> (a quarter of a second)
 
 =head2 running
 
-  $running = $rtf->running;
-  $rtf->running($boolean);
+  $running = $filter->running;
+  $filter->running($boolean);
 
 Are we running a filter?
 
@@ -215,8 +224,8 @@ Default: C<0>
 
 =head2 stop
 
-  $stop = $rtf->stop;
-  $rtf->stop($boolean);
+  $stop = $filter->stop;
+  $filter->stop($boolean);
 
 Stop running a filter.
 
